@@ -106,6 +106,18 @@
  *    - Multipathing support
  *    - Fix Medium Changer (and other device types with spaces) detection 
  *  -> 2.28
+ * 
+ *   * 2003-01-13: Kurt Garloff <garlof@suse.de>
+ *     - Handle EOF return value from sscanf()
+ *     - Handle empty names gracefully (for zfcp, from Bernd Kaindl)
+ *   * 2003-03-07: Kurt Garloff <garloff@suse.de>
+ *     - Fix symlinks to partitions (patch from Suresh Grandhi 
+ *	 <Sureshg@ami.com>)
+ *   * 2003-06-29: Kurt Garloff <garloff@suse.de>
+ *     - Fix fd leak (/proc/partitions)
+ *   * 2003-06-30: Kurt Garloff <garloff@suse.de>
+ *     - Empty name protection (2003-01-13) was faulty: Test was reversed.	
+ *   -> 2.29
  */
 
 #include <stdio.h>
@@ -126,11 +138,11 @@
 #include <ctype.h>
 
 
-static char rcsid[] ="$Id: scsidev.c,v 1.28.2.21 2002/10/04 12:42:09 garloff Exp $";
+static char rcsid[] ="$Id: scsidev.c,v 1.28.2.26 2003/06/30 11:24:48 garloff Exp $";
 static char *versid = "scsidev " VERSION " 2002-10-04";
 static char *copyright = "Copyright: GNU GPL  (see file COPYING)\n" \
 " (w)  1994--1997 Eric Youngdale <eric@andante.org>\n"\
-"      2000--2002 Kurt Garloff   <garloff@suse.de>";
+"      2000--2003 Kurt Garloff   <garloff@suse.de>";
 
 
 #include "config.h"
@@ -1631,6 +1643,7 @@ void create_partitions (sname * spnt)
 			}
 		}
 	}
+	fclose (pf);
 }
 	
 
@@ -1736,7 +1749,7 @@ void build_sgdevlist_procscsi ()
 		spnt = malloc (sizeof (sname));
 		memset (spnt, 0, sizeof (sname));
 		hl_per_dev = procscsi_parse (spnt);
-		if (!hl_per_dev) {
+		if (!hl_per_dev || hl_per_dev == EOF) {
 			free (spnt);
 			fprintf (stderr, "Low level dev without HL driver?\n");
 			continue;
@@ -1758,20 +1771,23 @@ void build_sgdevlist_procscsi ()
 		else
 			fill_in_proc (spnt);
 		if (!sgpnt)
-		    sgpnt = spnt;
+			sgpnt = spnt;
 		/* Copy info to the colleagues
 		 * and do special stuff depending on dev types. Such as the non-rew.
 		 * variant for tapes or the partitions on disks
 		 */
 		for (hl = 0; hl < hl_per_dev; ++hl, spnt = spnt->next) {
 			if (spnt != sgpnt) {
-				spnt->serial = strdup (sgpnt->serial);
+				if (sgpnt->serial) 
+					spnt->serial = strdup (sgpnt->serial);
 				spnt->wwid = sgpnt->wwid;
 				spnt->rmvbl = sgpnt->rmvbl;
 				//spnt->unsafe = sgpnt->unsafe;
 				spnt->hostid = sgpnt->hostid;
-				spnt->hostname = strdup (sgpnt->hostname);
-				spnt->shorthostname = strdup (sgpnt->shorthostname);
+				if (sgpnt->hostname)
+					spnt->hostname = strdup (sgpnt->hostname);
+				if (sgpnt->shorthostname) 
+					spnt->shorthostname = strdup (sgpnt->shorthostname);
 				spnt->related = sgpnt;
 			}
 			/* This does the handling of the dev nodes */
